Acknowledgments — A Python Environment for (phylogenetic) Tree Exploration

### Navigation

- index
- modules |
- ETE documentation »

# Acknowledgments

ETE is currently developed by the Comparative genomics group at the Centre for Genomic Regulation

Original authors and citation:

> Jaime Huerta-Cepas, Joaquín Dopazo and Toni Gabaldón.
> ETE: a python Environment for Tree Exploration. BMC Bioinformatics 2010, 11:2 4.

Thanks a lot to current and past contributors!:

- François Serra
- Salvador Capella
- Marina Marcet-Houben
- Ivan Denisov
- Cristina Amil

### Navigation

- index
- modules |
- ETE documentation »